@@ -46,10 +46,13 @@ def topic_directories(path) -> (list, list):
                     else:
                         directory_listing[t] = {isograd: {method: full_path_data}}
                     if method_listing.get(method):
-                        method_listing[method][isograd].extend(full_path_data)
+                        if method_listing[method].get(isograd):
+                            method_listing[method][isograd].extend(full_path_data)
+                        else:
+                            method_listing[method] = {isograd: full_path_data}
                     else:
                         method_listing[method] = {isograd: full_path_data}
-
+                        
                     if temperature_listing.get(isograd):
                         temperature_listing[isograd].append(temperature)
                     else:
